/// <reference types="node" />
import { bigInt } from 'snarkjs';
export declare namespace ErrorUtils {
    function ensureError<T extends Error>(value: unknown): T;
    function getError(message: string): Error;
}
export declare namespace AsyncUtils {
    type Callback = (...values: any[]) => Promise<any>;
    type ErrorHandler = (err: Error, numResolvedPromises: number, callbackIndex: number, orderIndex: number, ...args: any[]) => void;
    class PromisePooler {
        concurrencyLimit: number;
        private _totalAdded;
        _results: Array<any>;
        _callbacks: Array<Callback>;
        _errorHandlers: Array<ErrorHandler>;
        private _promises;
        constructor(callbacks: Array<Callback>, errorHandlers: Array<ErrorHandler>, concurrencyLimit: number);
        get pending(): number;
        get totalAdded(): number;
        poolMany(...args: Array<Array<any>>): Promise<void>;
        pool(...args: Array<any>): Promise<void>;
        all(): Promise<Array<any>>;
        race(): Promise<any>;
        reset(): Promise<Array<any>>;
        private _pool;
        private _getPromiseIndex;
        private _waitIfFull;
    }
    function timeout(msTimeout: number): Promise<any>;
    class SimpleMutex {
        private _mutexes;
        constructor();
        acquire(parentCallName: string): Promise<Function>;
    }
}
export declare namespace NumberUtils {
    function randomBigInteger(numBytes: number): typeof bigInt;
    function getRandomFromRange(lowerInclusive: number, upperInclusive: number, isInteger?: number): number;
}
export declare namespace HexUtils {
    function bufferToHex(buffer: Buffer, byteLen?: number): string;
    function numberToHex(number: number, byteLen?: number): string;
    function bigIntToHex(number: typeof bigInt, byteLen?: number): string;
    function prepareAddress(address: string, bytelen?: number): string;
}
export declare namespace ObjectUtils {
    export function populate<T extends Object>(source?: T, target?: T): T;
    type Swapped<T extends Object> = {
        left: T;
        right: T;
    };
    export function swap<T extends Object>(left: T, right: T): Swapped<T>;
    export function exists(obj: any): boolean;
    export {};
}
//# sourceMappingURL=index.d.ts.map